@@ -19,11 +19,11 @@ App::GitHooks::Utils - Support functions for App::GitHooks and its plugins.
 
 =head1 VERSION
 
-Version 1.4.0
+Version 1.5.0
 
 =cut
 
-our $VERSION = '1.4.0';
+our $VERSION = '1.5.0';
 
 
 =head2 get_project_prefixes()
@@ -95,11 +95,12 @@ sub get_project_prefix_regex
 }
 
 
-=head2 get_ticket_id_regex()
+=head2 get_ticket_id_from_commit_regex()
 
-Return a regex that will extract a ticket ID from a commit message, if it exists.
+Return a regex that will extract a ticket ID from a commit message, if it
+exists.
 
-	my $ticket_id_regex = App::GitHooks::Utils::get_ticket_id_regex( $app );
+	my $ticket_id_regex = App::GitHooks::Utils::get_ticket_id_from_commit_regex( $app );
 
 Arguments:
 
@@ -113,12 +114,16 @@ An C<App::GitHooks> instance.
 
 =cut
 
-sub get_ticket_id_regex
+sub get_ticket_id_from_commit_regex
 {
 	my ( $app ) = @_;
-
 	my $config = $app->get_config();
-	my $ticket_regex = $config->get_regex( '_', 'extract_ticket_id_from_branch' ) // '^($project_prefixes)-?(\d+)';
+
+	# Retrieve the regular expression from the config or use a default.
+	my $ticket_regex = $app->get_config()->get_regex( '_', 'extract_ticket_id_from_commit' )
+		// '^($project_prefixes-\d+|--)\: ';
+
+	# Replace the list of project prefixes if it is mentioned in the regex.
 	my $project_prefix_regex = get_project_prefix_regex( $app );
 	$ticket_regex =~ s/\$project_prefixes/$project_prefix_regex/g;
 
